summaryrefslogtreecommitdiffstats
path: root/kstars/kstars
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:27 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:27 -0600
commit9f2c757e1a1694373c11427a00502c2ff4c2d403 (patch)
tree7d90e91214976a7d23d89ec3474515cf46069704 /kstars/kstars
parentcee429821aa6f1acc97fb482d325fb4eb37376ca (diff)
downloadtdeedu-9f2c757e1a1694373c11427a00502c2ff4c2d403.tar.gz
tdeedu-9f2c757e1a1694373c11427a00502c2ff4c2d403.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kstars/kstars')
-rw-r--r--kstars/kstars/ccdpreviewwg.cpp2
-rw-r--r--kstars/kstars/colorscheme.cpp4
-rw-r--r--kstars/kstars/colorscheme.h6
-rw-r--r--kstars/kstars/imageviewer.cpp8
-rw-r--r--kstars/kstars/imageviewer.h4
-rw-r--r--kstars/kstars/kstarsactions.cpp12
-rw-r--r--kstars/kstars/kstarsdcop.cpp4
-rw-r--r--kstars/kstars/skymap.h2
-rw-r--r--kstars/kstars/streamwg.cpp2
-rw-r--r--kstars/kstars/thumbnailpicker.cpp24
-rw-r--r--kstars/kstars/thumbnailpicker.h4
-rw-r--r--kstars/kstars/tools/lcgenerator.cpp6
-rw-r--r--kstars/kstars/tools/lcgenerator.h4
-rw-r--r--kstars/kstars/tools/observinglist.cpp2
-rw-r--r--kstars/kstars/tools/scriptbuilder.cpp4
15 files changed, 44 insertions, 44 deletions
diff --git a/kstars/kstars/ccdpreviewwg.cpp b/kstars/kstars/ccdpreviewwg.cpp
index edbc9006..cff58b6c 100644
--- a/kstars/kstars/ccdpreviewwg.cpp
+++ b/kstars/kstars/ccdpreviewwg.cpp
@@ -261,7 +261,7 @@ void CCDPreviewWG::captureImage()
if ( tmpfile.name() == fname )
{ //need to upload to remote location
- if ( ! KIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) )
+ if ( ! TDEIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) )
{
TQString message = i18n( "Could not upload image to remote location: %1" ).arg( currentFileURL.prettyURL() );
KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
diff --git a/kstars/kstars/colorscheme.cpp b/kstars/kstars/colorscheme.cpp
index 5449c48e..7dbacf05 100644
--- a/kstars/kstars/colorscheme.cpp
+++ b/kstars/kstars/colorscheme.cpp
@@ -290,7 +290,7 @@ bool ColorScheme::save( const TQString &name ) {
return true;
}
-void ColorScheme::loadFromConfig( KConfig *conf ) {
+void ColorScheme::loadFromConfig( TDEConfig *conf ) {
TQStringList::Iterator it = KeyName.begin();
TQStringList::Iterator it_end = KeyName.end();
for ( ; it != it_end; ++it )
@@ -300,7 +300,7 @@ void ColorScheme::loadFromConfig( KConfig *conf ) {
setStarColorIntensity( conf->readNumEntry( "StarColorIntensity", 5 ) );
}
-void ColorScheme::saveToConfig( KConfig *conf ) {
+void ColorScheme::saveToConfig( TDEConfig *conf ) {
TQStringList::Iterator it = KeyName.begin();
TQStringList::Iterator it_end = KeyName.end();
for ( ; it != it_end; ++it )
diff --git a/kstars/kstars/colorscheme.h b/kstars/kstars/colorscheme.h
index 22edb1e6..696abcc0 100644
--- a/kstars/kstars/colorscheme.h
+++ b/kstars/kstars/colorscheme.h
@@ -21,7 +21,7 @@
#include <tqmap.h>
#include <tqstringlist.h>
-class KConfig;
+class TDEConfig;
/**
*@class ColorScheme
@@ -114,11 +114,11 @@ class ColorScheme {
/**Read color-scheme data from the Config object.
*/
- void loadFromConfig( KConfig* );
+ void loadFromConfig( TDEConfig* );
/**Save color-scheme data to the Config object.
*/
- void saveToConfig( KConfig* );
+ void saveToConfig( TDEConfig* );
/**@return the number of colors in the color scheme.*/
unsigned int numberOfColors() const { return (int)Palette.size(); }
diff --git a/kstars/kstars/imageviewer.cpp b/kstars/kstars/imageviewer.cpp
index 9d07fc64..8b0acacb 100644
--- a/kstars/kstars/imageviewer.cpp
+++ b/kstars/kstars/imageviewer.cpp
@@ -131,11 +131,11 @@ void ImageViewer::loadImageFromURL()
if (!saveURL.isValid())
kdDebug()<<"tempfile-URL is malformed\n";
- downloadJob = KIO::copy (imageURL, saveURL); // starts the download asynchron
- connect (downloadJob, TQT_SIGNAL (result (KIO::Job *)), TQT_SLOT (downloadReady (KIO::Job *)));
+ downloadJob = TDEIO::copy (imageURL, saveURL); // starts the download asynchron
+ connect (downloadJob, TQT_SIGNAL (result (TDEIO::Job *)), TQT_SLOT (downloadReady (TDEIO::Job *)));
}
-void ImageViewer::downloadReady (KIO::Job *job)
+void ImageViewer::downloadReady (TDEIO::Job *job)
{
// set downloadJob to 0, but don't delete it - the job will automatically deleted !!!
downloadJob = 0;
@@ -223,7 +223,7 @@ void ImageViewer::saveFileToDisc()
void ImageViewer::saveFile (KURL &url) {
// synchronous Access to prevent segfaults
- if (!KIO::NetAccess::copy (KURL (file->name()), url, (TQWidget*) 0))
+ if (!TDEIO::NetAccess::copy (KURL (file->name()), url, (TQWidget*) 0))
{
TQString text = i18n ("Saving of the image %1 failed.");
KMessageBox::error (this, text.arg (url.prettyURL() ));
diff --git a/kstars/kstars/imageviewer.h b/kstars/kstars/imageviewer.h
index fa1873e4..3bae7a27 100644
--- a/kstars/kstars/imageviewer.h
+++ b/kstars/kstars/imageviewer.h
@@ -110,11 +110,11 @@ class ImageViewer : public KMainWindow {
TQString filename;
bool ctrl, key_s, key_q; // the keys
- KIO::Job *downloadJob; // download job of image -> 0 == no job is running
+ TDEIO::Job *downloadJob; // download job of image -> 0 == no job is running
private slots:
/**Make sure download has finished, then make sure file exists, then display the image */
- void downloadReady (KIO::Job *);
+ void downloadReady (TDEIO::Job *);
/**Saves. File. To. Disc. */
void saveFileToDisc( void );
diff --git a/kstars/kstars/kstarsdcop.cpp b/kstars/kstars/kstarsdcop.cpp
index 11f71f17..1c755175 100644
--- a/kstars/kstars/kstarsdcop.cpp
+++ b/kstars/kstars/kstarsdcop.cpp
@@ -210,7 +210,7 @@ TQString KStars::getOption( const TQString &name ) {
if ( name == "FocusRA" ) { return TQString::number( map()->focus()->ra()->Hours(), 'f', 6 ); }
if ( name == "FocusDec" ) { return TQString::number( map()->focus()->dec()->Degrees(), 'f', 6 ); }
- KConfigSkeletonItem *it = Options::self()->findItem( name );
+ TDEConfigSkeletonItem *it = Options::self()->findItem( name );
if ( it ) return it->property().toString();
else return TQString();
}
@@ -451,7 +451,7 @@ void KStars::exportImage( const TQString url, int w, int h ) {
else kdDebug() << i18n( "Image saved to file: %1" ).arg( fname ) << endl;
if ( tmpfile.name() == fname ) { //attempt to upload image to remote location
- if ( ! KIO::NetAccess::upload( tmpfile.name(), fileURL, this ) ) {
+ if ( ! TDEIO::NetAccess::upload( tmpfile.name(), fileURL, this ) ) {
TQString message = i18n( "Could not upload image to remote location: %1" ).arg( fileURL.prettyURL() );
KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
}
diff --git a/kstars/kstars/skymap.h b/kstars/kstars/skymap.h
index 6ad0b86d..5938afe1 100644
--- a/kstars/kstars/skymap.h
+++ b/kstars/kstars/skymap.h
@@ -61,7 +61,7 @@ class SkyMap : public TQWidget {
public:
/**
- *Constructor. Read stored settings from KConfig object (focus position,
+ *Constructor. Read stored settings from TDEConfig object (focus position,
*zoom factor, sky color, etc.). Run initPopupMenus().
*/
SkyMap( KStarsData *d, TQWidget *parent=0, const char *name=0);
diff --git a/kstars/kstars/streamwg.cpp b/kstars/kstars/streamwg.cpp
index e6796bcb..86d73a01 100644
--- a/kstars/kstars/streamwg.cpp
+++ b/kstars/kstars/streamwg.cpp
@@ -252,7 +252,7 @@ void StreamWG::captureImage()
if ( tmpfile.name() == fname )
{ //need to upload to remote location
- if ( ! KIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) )
+ if ( ! TDEIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) )
{
TQString message = i18n( "Could not upload image to remote location: %1" ).arg( currentFileURL.prettyURL() );
KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
diff --git a/kstars/kstars/thumbnailpicker.cpp b/kstars/kstars/thumbnailpicker.cpp
index 237eaa85..f568dbec 100644
--- a/kstars/kstars/thumbnailpicker.cpp
+++ b/kstars/kstars/thumbnailpicker.cpp
@@ -107,15 +107,15 @@ void ThumbnailPicker::slotFillList() {
for ( ; itList != itListEnd; ++itList ) {
TQString s( *itList );
KURL u( s );
- if ( u.isValid() && KIO::NetAccess::exists(u, true, this) ) {
+ if ( u.isValid() && TDEIO::NetAccess::exists(u, true, this) ) {
KTempFile ktf;
TQFile *tmpFile = ktf.file();
ktf.unlink(); //just need filename
- JobList.append( KIO::copy( u, KURL( tmpFile->name() ), false ) ); //false = no progress window
+ JobList.append( TDEIO::copy( u, KURL( tmpFile->name() ), false ) ); //false = no progress window
#if KDE_IS_VERSION( 3, 3, 90 )
- ((KIO::CopyJob*)JobList.current())->setInteractive( false ); // suppress error dialogs
+ ((TDEIO::CopyJob*)JobList.current())->setInteractive( false ); // suppress error dialogs
#endif
- connect (JobList.current(), TQT_SIGNAL (result(KIO::Job *)), TQT_SLOT (downloadReady (KIO::Job *)));
+ connect (JobList.current(), TQT_SIGNAL (result(TDEIO::Job *)), TQT_SLOT (downloadReady (TDEIO::Job *)));
}
}
@@ -126,7 +126,7 @@ void ThumbnailPicker::parseGooglePage( TQStringList &ImList, TQString URL ) {
TQString PageHTML;
//Read the google image page's HTML into the PageHTML TQString:
- if ( KIO::NetAccess::exists(URL, true, this) && KIO::NetAccess::download( URL, tmpFile ) ) {
+ if ( TDEIO::NetAccess::exists(URL, true, this) && TDEIO::NetAccess::download( URL, tmpFile ) ) {
TQFile file( tmpFile );
if ( file.open( IO_ReadOnly ) ) {
TQTextStream instream(&file);
@@ -137,7 +137,7 @@ void ThumbnailPicker::parseGooglePage( TQStringList &ImList, TQString URL ) {
return;
}
} else {
- kdDebug() << KIO::NetAccess::lastErrorString() << endl;
+ kdDebug() << TDEIO::NetAccess::lastErrorString() << endl;
return;
}
@@ -152,7 +152,7 @@ void ThumbnailPicker::parseGooglePage( TQStringList &ImList, TQString URL ) {
}
}
-void ThumbnailPicker::downloadReady(KIO::Job *job) {
+void ThumbnailPicker::downloadReady(TDEIO::Job *job) {
//Note: no need to delete the job, it is automatically deleted !
//Update Progressbar
@@ -170,7 +170,7 @@ void ThumbnailPicker::downloadReady(KIO::Job *job) {
return;
}
- KIO::CopyJob *cjob = (KIO::CopyJob*)job;
+ TDEIO::CopyJob *cjob = (TDEIO::CopyJob*)job;
TQFile tmp( cjob->destURL().path() );
tmp.close(); // to get the newest information of the file
@@ -335,15 +335,15 @@ void ThumbnailPicker::slotSetFromURL() {
ui->ImageList->setCurrentItem( 0 );
slotSetFromList(0);
- } else if ( KIO::NetAccess::exists(u, true, this) ) {
+ } else if ( TDEIO::NetAccess::exists(u, true, this) ) {
KTempFile ktf;
TQFile *tmpFile = ktf.file();
ktf.unlink(); //just need filename
- JobList.append( KIO::copy( u, KURL( tmpFile->name() ), false ) ); //false = no progress window
+ JobList.append( TDEIO::copy( u, KURL( tmpFile->name() ), false ) ); //false = no progress window
#if KDE_IS_VERSION( 3, 3, 90 )
- ((KIO::CopyJob*)JobList.current())->setInteractive( false ); // suppress error dialogs
+ ((TDEIO::CopyJob*)JobList.current())->setInteractive( false ); // suppress error dialogs
#endif
- connect (JobList.current(), TQT_SIGNAL (result(KIO::Job *)), TQT_SLOT (downloadReady (KIO::Job *)));
+ connect (JobList.current(), TQT_SIGNAL (result(TDEIO::Job *)), TQT_SLOT (downloadReady (TDEIO::Job *)));
//
}
diff --git a/kstars/kstars/thumbnailpicker.h b/kstars/kstars/thumbnailpicker.h
index 840e3bd5..89346989 100644
--- a/kstars/kstars/thumbnailpicker.h
+++ b/kstars/kstars/thumbnailpicker.h
@@ -55,7 +55,7 @@ private slots:
void slotFillList();
/**Make sure download has finished, then make sure file exists, then add image to list */
- void downloadReady (KIO::Job *);
+ void downloadReady (TDEIO::Job *);
private:
TQPixmap shrinkImage( TQPixmap *original, int newSize, bool setImage=false );
@@ -66,7 +66,7 @@ private:
TQPixmap *Image;
DetailDialog *dd;
SkyObject *Object;
- TQPtrList<KIO::Job> JobList;
+ TQPtrList<TDEIO::Job> JobList;
TQPtrList<TQPixmap> PixList;
bool bImageFound;
TQRect *ImageRect;
diff --git a/kstars/kstars/tools/lcgenerator.cpp b/kstars/kstars/tools/lcgenerator.cpp
index b309233e..a07bfc50 100644
--- a/kstars/kstars/tools/lcgenerator.cpp
+++ b/kstars/kstars/tools/lcgenerator.cpp
@@ -426,11 +426,11 @@ void LCGenerator::updateStarList()
KURL AAVSOFile("http://www.aavso.org/observing/aids/valaav.txt");
KURL saveFile (file->name());
- downloadJob = KIO::file_copy (AAVSOFile, saveFile, -1, true);
- connect (downloadJob, TQT_SIGNAL (result (KIO::Job *)), TQT_SLOT (downloadReady (KIO::Job *)));
+ downloadJob = TDEIO::file_copy (AAVSOFile, saveFile, -1, true);
+ connect (downloadJob, TQT_SIGNAL (result (TDEIO::Job *)), TQT_SLOT (downloadReady (TDEIO::Job *)));
}
-void LCGenerator::downloadReady(KIO::Job * job)
+void LCGenerator::downloadReady(TDEIO::Job * job)
{
downloadJob = 0;
diff --git a/kstars/kstars/tools/lcgenerator.h b/kstars/kstars/tools/lcgenerator.h
index 8245c04f..04fa8841 100644
--- a/kstars/kstars/tools/lcgenerator.h
+++ b/kstars/kstars/tools/lcgenerator.h
@@ -126,7 +126,7 @@ private:
TQHBoxLayout* ButtonHLayout;
- KIO::Job *downloadJob; // download job of image -> 0 == no job is running
+ TDEIO::Job *downloadJob; // download job of image -> 0 == no job is running
TQFile *file;
@@ -155,7 +155,7 @@ public slots:
void updateStarList();
/** Reload file and update lists after download */
- void downloadReady(KIO::Job *);
+ void downloadReady(TDEIO::Job *);
};
#endif // LCGENERATOR_H
diff --git a/kstars/kstars/tools/observinglist.cpp b/kstars/kstars/tools/observinglist.cpp
index 17fa8cce..063e4b5f 100644
--- a/kstars/kstars/tools/observinglist.cpp
+++ b/kstars/kstars/tools/observinglist.cpp
@@ -519,7 +519,7 @@ void ObservingList::slotOpenList() {
KTempFile tmpfile;
tmpfile.setAutoDelete(true);
FileName = tmpfile.name();
- if( KIO::NetAccess::download( fileURL, FileName, this ) )
+ if( TDEIO::NetAccess::download( fileURL, FileName, this ) )
f.setName( FileName );
} else {
diff --git a/kstars/kstars/tools/scriptbuilder.cpp b/kstars/kstars/tools/scriptbuilder.cpp
index 9e02efe0..7a31fbf1 100644
--- a/kstars/kstars/tools/scriptbuilder.cpp
+++ b/kstars/kstars/tools/scriptbuilder.cpp
@@ -753,7 +753,7 @@ void ScriptBuilder::slotOpen() {
fname = currentFileURL.path();
} else {
fname = tmpfile.name();
- if ( ! KIO::NetAccess::download( currentFileURL, fname, (TQWidget*) 0 ) )
+ if ( ! TDEIO::NetAccess::download( currentFileURL, fname, (TQWidget*) 0 ) )
KMessageBox::sorry( 0, i18n( "Could not download remote file." ), i18n( "Download Error" ) );
}
@@ -833,7 +833,7 @@ void ScriptBuilder::slotSave() {
chmod( fname.ascii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH );
if ( tmpfile.name() == fname ) { //need to upload to remote location
- if ( ! KIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) ) {
+ if ( ! TDEIO::NetAccess::upload( tmpfile.name(), currentFileURL, (TQWidget*) 0 ) ) {
TQString message = i18n( "Could not upload image to remote location: %1" ).arg( currentFileURL.prettyURL() );
KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
}
diff --git a/kstars/kstars/kstarsactions.cpp b/kstars/kstars/kstarsactions.cpp
index 4e28a5ab..dfa392b3 100644
--- a/kstars/kstars/kstarsactions.cpp
+++ b/kstars/kstars/kstarsactions.cpp
@@ -350,10 +350,10 @@ void KStars::slotViewOps() {
//An instance of your dialog could be already created and could be cached,
//in which case you want to display the cached dialog instead of creating
//another one
- if ( KConfigDialog::showDialog( "settings" ) ) return;
+ if ( TDEConfigDialog::showDialog( "settings" ) ) return;
- //KConfigDialog didn't find an instance of this dialog, so lets create it :
- KConfigDialog* dialog = new KConfigDialog( this, "settings",
+ //TDEConfigDialog didn't find an instance of this dialog, so lets create it :
+ TDEConfigDialog* dialog = new TDEConfigDialog( this, "settings",
Options::self() );
connect( dialog, TQT_SIGNAL( applyClicked() ), TQT_TQOBJECT(this), TQT_SLOT( slotApplySettings() ) );
@@ -496,11 +496,11 @@ void KStars::slotRunScript() {
fname = tmpfile.name();
}
- if( KIO::NetAccess::download( fileURL, fname, this ) ) {
+ if( TDEIO::NetAccess::download( fileURL, fname, this ) ) {
chmod( fname.ascii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH ); //make it executable
if ( tmpfile.name() == fname ) { //upload to remote location
- if ( ! KIO::NetAccess::upload( tmpfile.name(), fileURL, this ) ) {
+ if ( ! TDEIO::NetAccess::upload( tmpfile.name(), fileURL, this ) ) {
TQString message = i18n( "Could not upload image to remote location: %1" ).arg( fileURL.prettyURL() );
KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
}
@@ -519,7 +519,7 @@ void KStars::slotRunScript() {
if ( ! fileURL.isLocalFile() ) {
fname = tmpfile.name();
- if( KIO::NetAccess::download( fileURL, fname, this ) ) {
+ if( TDEIO::NetAccess::download( fileURL, fname, this ) ) {
chmod( fname.ascii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH );
f.setName( fname );
}